import { FC } from "react";
import { Language } from "../types/Language";
import { UITranslation } from "../types/UITranslation";
import { ConventionSeries } from "../types/ConventionSeries";
import clsx from "clsx";
import { FlagsUI, LanguageUI } from "../lib/flags";
import { appStateParse, appStateSerialize } from "../lib/appState";

export type ChangeLanguageModalProps = {
  show: boolean;
  close: () => void;
  UIStrings: Record<Language, UITranslation>;
  lang: Language;
  conventionSeries: ConventionSeries;
  rerender: () => void;
};

export const ChangeLanguageModal: FC<ChangeLanguageModalProps> = ({
  show,
  close,
  UIStrings,
  lang,
  conventionSeries,
  rerender,
}) => {
  const setLanguage = (newLang: Language) => {
    const [, oldPage, oldTab, oldHash] = appStateParse(
      window.location.hash.substring(1)
    )!;
    window.location.replace(
      `#${appStateSerialize([newLang, oldPage, oldTab, oldHash])}`
    );
    rerender();
  };
  return (
    <div className={clsx("modal", show || "hidden")} onClick={close}>
      <div className="modal-content" onClick={() => null}>
        <ul>
          {conventionSeries.languages.map((cand) => (
            <li
              key={cand}
              className={clsx(lang === cand && "selected")}
              onClick={() => setLanguage(cand)}
            >
              <span style={{ paddingRight: "0.5rem" }}>
                {UIStrings[cand][FlagsUI[cand]]}
              </span>
              {UIStrings[cand][LanguageUI[cand]]}
            </li>
          ))}
        </ul>
      </div>
    </div>
  );
};
