import { Language } from "../types/Language";
import { appStateParse } from "../lib/appState";
import { ConventionEdition } from "../types/ConventionEdition";
import Image from "next/image";
import { FC } from "react";
import { UITranslation } from "../types/UITranslation";

type ConMapProps = {
  UIStrings: Record<Language, UITranslation>;
  conventionEdition: ConventionEdition;
  mediaPrefix: string;
};

export const ConMap: FC<ConMapProps> = ({
  UIStrings,
  conventionEdition,
  mediaPrefix,
}) => {
  const lang =
    appStateParse(window.location.hash.substring(1))?.[0] ??
    conventionEdition.language;
  const imageUuid = appStateParse(window.location.hash.substring(1))?.[3];
  const img = conventionEdition.maps.find((x) => x.uuid === imageUuid);
  const pressBack = () => window.history.back();
  if (img === undefined) {
    pressBack();
  }
  return (
    <div className="imageView">
      <div className="backButton">
        <Image
          src="/icons/ic_arrow_back_black_24dp.svg"
          alt={UIStrings[lang].menu_continue_in_background}
          width={32}
          height={32}
          style={{ filter: "invert(1)" }}
          onClick={pressBack}
        />
      </div>
      {img !== undefined && (
        // eslint-disable-next-line @next/next/no-img-element
        <img src={`${mediaPrefix}${img.image[lang]}`} alt="" loading="lazy" />
      )}
    </div>
  );
};
