import Link from "next/link";
import { appStateParse } from "../lib/appState";
import { langDateFormatter, FormattingStyle } from "../lib/langDateFormatter";
import { ConventionEdition } from "../types/ConventionEdition";
import { ConventionSeries } from "../types/ConventionSeries";
import { FC } from "react";

type MasterFragmentNotificationProps = {
  conventionEdition: ConventionEdition;
  conventionSeries: ConventionSeries;
};

export const MasterFragmentNotification: FC<
  MasterFragmentNotificationProps
> = ({ conventionEdition, conventionSeries }) => {
  const lang =
    appStateParse(window.location.hash.substring(1))?.[0] ??
    conventionEdition.language;
  return (
    <ul className="announcements">
      {conventionSeries.announcements.map((announcement) => (
        <Link
          href={announcement.link[lang]}
          key={announcement.uuid}
          target="_blank"
          rel="noreferrer"
        >
          <li>
            <div className="timestamp">
              <span className="dow">
                {langDateFormatter(
                  FormattingStyle.DayOfWeek,
                  lang,
                  conventionEdition.timezone,
                  announcement.modified
                )}
              </span>
              <span className="date">
                {langDateFormatter(
                  FormattingStyle.MonthName,
                  lang,
                  conventionEdition.timezone,
                  announcement.modified
                )}{" "}
                {langDateFormatter(
                  FormattingStyle.DayOfMonth,
                  lang,
                  conventionEdition.timezone,
                  announcement.modified
                )}
              </span>
              <span className="time">
                {langDateFormatter(
                  FormattingStyle.HoursAndMinutes,
                  lang,
                  conventionEdition.timezone,
                  announcement.modified
                )}
              </span>
            </div>
            <article style={{ whiteSpace: "pre-line" }}>
              <h3>{announcement.title[lang]}</h3>
              {announcement.body[lang]}
            </article>
            <i
              className="icon"
              style={{
                maskImage: `url("/icons/ic_link.svg")`,
                WebkitMaskImage: `url("/icons/ic_link.svg")`,
              }}
            />
          </li>
        </Link>
      ))}
    </ul>
  );
};
