import { appStateParse } from "../lib/appState";
import { compare } from "../lib/compare";
import { ConventionEdition } from "../types/ConventionEdition";
import { ConventionSeries } from "../types/ConventionSeries";
import { Language } from "../types/Language";
import { UITranslation } from "../types/UITranslation";
import { FC } from "react";
import { RuleExpander } from "./RuleExpander";

type MasterFragmentRulesProps = {
  UIStrings: Record<Language, UITranslation>;
  conventionSeries: ConventionSeries;
  conventionEdition: ConventionEdition;
};

export const MasterFragmentRules: FC<MasterFragmentRulesProps> = ({
  UIStrings,
  conventionEdition,
  conventionSeries,
}) => {
  const lang =
    appStateParse(window.location.hash.substring(1))?.[0] ??
    conventionEdition.language;
  const rules: [string, string, string][] = [
    [
      "statute",
      UIStrings[lang].convention_rules,
      conventionSeries.statute[lang],
    ],
    ...(conventionEdition.additional_rules
      .sort(
        (a, b) =>
          compare(a.ordering, b.ordering) ??
          compare(
            a.name[conventionEdition.language],
            b.name[conventionEdition.language]
          )
      )
      .map((ar) => [ar.uuid, ar.name[lang], ar.rules[lang]]) satisfies [
      string,
      string,
      string
    ][]),
  ];
  return (
    <ul className="rules">
      {rules.map(([idtf, title, body]) => (
        <li key={idtf}>
          <RuleExpander title={title} body={body} />
        </li>
      ))}
    </ul>
  );
};
