import { ReactNode } from "react";
import { TextWithColor } from "../types/TextWithColor";
import { Language } from "../types/Language";
import { zip } from "./zip";

const LuminanceCoefficients = {
  CCIR601: [0.299, 0.587, 0.114],
  BT709: [0.2126, 0.7152, 0.0722],
  SMPTE240M: [0.212, 0.701, 0.087],
} as const;

const LuminanceCoefficient = LuminanceCoefficients.BT709 as readonly number[];

const GAMUT = 1.8;

const normColor = (s: string): string => (s.startsWith("#") ? s : "#" + s);
const color2int3 = (s: string): [number, number, number] => [
  parseInt(normColor(s).substring(1).substring(0, 2), 16),
  parseInt(normColor(s).substring(3).substring(0, 2), 16),
  parseInt(normColor(s).substring(5).substring(0, 2), 16),
];
const chooseColorsBewteenFor = (bkg: string, fgds: string[]): string => {
  if (fgds.length == 1) return fgds[0];
  if (fgds.length == 0) {
    fgds.push("#000000");
    fgds.push("#FFFFFF");
  }
  return fgds
    .map(
      (fgd) =>
        [
          fgd,
          zip(
            zip(color2int3(bkg), color2int3(fgd)).map(([a, b]) =>
              Math.abs(a - b)
            ),
            LuminanceCoefficient.map((x) => x)
          )
            .map(
              ([colorChannel, luminanceCoefficient]) =>
                Math.pow(colorChannel, GAMUT) * luminanceCoefficient
            )
            .reduce((s, c) => s + c, 0),
        ] satisfies [string, number]
    )
    .sort((a, b) => b[1] - a[1])[0][0];
};

export const applyColorTo = (
  lang: Language,
  twc: TextWithColor,
  altColors: string[]
): ReactNode => (
  <span
    className="paintedTag"
    style={{
      backgroundColor: normColor(twc.color.color),
      color: chooseColorsBewteenFor(
        normColor(twc.color.color),
        altColors.map(normColor)
      ),
    }}
  >
    {twc.label[lang]}
  </span>
);
